Examples of scripts
===================

You can find examples for scripts (loosely based on the scripts for the official python bindings for gnucash or on
questions posted on the mailing list) in the examples subfolder.

Creating and opening gnucash files
----------------------------------
.. literalinclude:: ../../../examples/simple_session.py

Creating an account
-------------------
.. literalinclude:: ../../../examples/simple_sqlite_create.py

Creating a transaction
----------------------
.. literalinclude:: ../../../examples/simple_test.py

Simple changes on a newly created book
--------------------------------------
.. literalinclude:: ../../../examples/simple_book.py

Filtered transaction reports
----------------------------
.. literalinclude:: ../../../examples/filtered_transaction_report.py

